<?php

namespace ApnaComplex\Http\Controllers\Auth;

use ApnaComplex\User;
use ApnaComplex\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Auth\Events\Registered;
use Illuminate\Http\Request;
use DB;
class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = '/success';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => 'required|string|max:255',
            'email' => 'required|string|email|max:255|unique:users',
            'password' => 'required|string|min:6|confirmed',
			'apartmentId' => 'required',
			'group_id' => 'required',
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \ApnaComplex\User
     */
	 
    protected function create(array $data)
    {
		$username= uniqid($data['name']);
        
		
        $userData=  User::create([
            'name' => $data['name'],
			'username'=>$username,
            'email' => $data['email'],
            'password' => bcrypt($data['password']),
			'city' => $data['city'],
			'pincode' => $data['pincode'],
			'mobile' => $data['mobile'],
			'activationcode' => null,
			'userimage'=>null,
			'status' => 0
        ]);
		
		if(!empty($userData)){
			$apartmentId= $data['apartmentId'];
			if(isset($data['roles_list'])){	
			 
			   $roles= $data['roles_list'];
			   
			    foreach($roles as $role){
				    $data= array(
						'group_id' => $data['group_id'],
						'apartment_id' =>$apartmentId,
						'user_id' => $userData->id,
						'role_id'    => $role,		
					);
				    DB::table('users_groups')->insert($data);
			    }
			 
		    }
			else{
				
				$data= array(
					'group_id' => $data['group_id'],
					'apartment_id' =>$apartmentId,
					'user_id' => $userData->id,
						
		        );
			
		        DB::table('users_groups')->insert($data);
				
			}
		    
		   
		   //$userData['grouData']=$data;
		}
		
		
		//echo "<pre>";print_r($userData); die;
		return $userData;
    }
	
	public function register(Request $request)
    {
		
        $this->validator($request->all())->validate();

        event(new Registered($user = $this->create($request->all())));

        //$this->guard()->login($user);

        return $this->registered($request, $user)
                        ?: redirect($this->redirectPath());
    }
	
	public function showRegistrationForm()
	{
		$data['apartments']= DB::select('select apartment_name,id from apartments where status=1');
		
		return view("auth.register", $data);
	}
}
